@@ -6,5 +6,4 @@
 #undef HAVE_GETTEXT
 #undef HAVE_LC_MESSAGES
 #undef HAVE_STPCPY
-#undef CHESS_ENGINE_CRAFTY
-#undef CHESS_ENGINE_GNUCHESS
+#undef GETTEXT_PACKAGE
