@@ -27,10 +27,7 @@
 #include <gnome.h>
 #include "game-view.h"
 
-#ifdef __cplusplus
-extern "C" {
-#pragma }
-#endif /* __cplusplus */
+G_BEGIN_DECLS
 
 #define BOARD_TYPE_WINDOW			(board_window_get_type ())
 #define BOARD_WINDOW(obj)			(GTK_CHECK_CAST ((obj), BOARD_TYPE_WINDOW, BoardWindow))
@@ -72,9 +69,7 @@ void       board_window_add_info            (BoardWindow *window,
 void       board_window_remove_info         (BoardWindow *window,
 					     GtkWidget   *child);
 
-#ifdef __cplusplus
-}
-#endif /* __cplusplus */
+G_END_DECLS
 
-#endif /* _BOARD_WINDOW_H_ */
+#endif
 
