@@ -22,52 +22,28 @@
 #include <unistd.h>
 #include <signal.h>
 
+#include <sys/types.h>
+#include <sys/wait.h>
+
 #include "debug.h"
 #include "child.h"
 
 int 
-start_child (char *cmd, 
-	     char **arg, 
+start_child (char **arg, 
 	     GIOChannel **read_chan, 
 	     GIOChannel **write_chan, 
 	     pid_t *childpid)
 {
-	int pipe1[2], pipe2[2];
+	gint in, out, err;
+	
+	if (!g_spawn_async_with_pipes (NULL, arg, NULL, G_SPAWN_SEARCH_PATH,
+				       NULL, NULL, childpid, &in, &out, &err, NULL))
+		return -1;
+	
+	*read_chan = g_io_channel_unix_new (out);
+	*write_chan = g_io_channel_unix_new (in);
 
-	if ((pipe (pipe1) <0) || (pipe (pipe2) < 0)) {
-		perror ("pipe");
-		exit (-1);
-	}
-
-	if ((*childpid = fork ()) < 0) {
-		perror ("fork");
-		exit (-1);
-	} else if (*childpid > 0) /* Parent */ {
-		close (pipe1[0]);
-		close (pipe2[1]);
-
-		*read_chan = g_io_channel_unix_new (pipe2[0]);
-		*write_chan = g_io_channel_unix_new (pipe1[1]);
-
-		return *childpid;
-	} else   /* Child */ {
-		close (pipe1[1]);
-		close (pipe2[0]);
-
-		dup2 (pipe1[0],0);
-		dup2 (pipe2[1],1);
-
-		close (pipe1[0]);
-		close (pipe2[1]);
-
-		if (execvp (cmd, arg) < 0)
-			perror (cmd);
-		_exit (1);
-	}
-
-	g_assert_not_reached ();
-
-	return 0;
+	return *childpid;
 }
 
 void 
@@ -102,5 +78,7 @@ stop_child (pid_t childpid)
 		return 1;
 	}
 
+	waitpid(childpid, NULL, 0);
+
 	return 0;
 }
