@@ -16,8 +16,29 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
  */
 
-#include <stdarg.h>
-#include <stdio.h>
+#ifndef _CHILD_H_
+#define _CHILD_H_
+
+#include <sys/types.h>
+#include <glib.h>
+
+G_BEGIN_DECLS
+
+int  start_child (char       **arg,
+		  GIOChannel **read_chan,
+		  GIOChannel **write_chan,
+		  pid_t       *childpid);
+
+void write_child (GIOChannel  *write_chan,
+		  char        *format,
+		  ...);
+
+int  stop_child  (pid_t        childpid);
+
+G_END_DECLS
+
+#endif
+
+
+
 
-int start_child(char *cmd, char **arg, FILE **readpipe, FILE **writepipe,pid_t *childpid);
-int stop_child(pid_t childpid);
