@@ -27,7 +27,7 @@ set_ok (GtkWidget *widget, gboolean *dialog_result)
 	gtk_main_quit ();
 }
 
-gchar *
+char *
 filesel (const char *desc, const char *def)
 {
 	GtkFileSelection *fsel;
@@ -48,10 +48,8 @@ filesel (const char *desc, const char *def)
 	gtk_grab_add (GTK_WIDGET (fsel));
 	gtk_main ();
 
-	if (accepted) {
-		gchar *name = gtk_file_selection_get_filename (fsel);
-		rname = g_strdup (name);
-	}
+	if (accepted)
+		rname = g_strdup (gtk_file_selection_get_filename (fsel));
 
 	gtk_widget_destroy (GTK_WIDGET (fsel));
 	return rname;
