@@ -19,6 +19,6 @@
 #ifndef _COMMON_H_
 #define _COMMON_H_
 
-gchar *filesel (const char *desc, const char *def);
+char *filesel (const char *desc, const char *def);
 
 #endif
