@@ -16,18 +16,20 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
  */
 
-#include "gnome_chess.h"
 #include <stdarg.h>
+#include <stdio.h>
+
 #include "debug.h"
 
 int debug = DEBUG_NONE;
 
-void debug_print(int level, char *format, ...) {
+void
+debug_print (int level, char *format, ...)
+{
 	va_list ap;
 
-	va_start(ap,format);
-	if (debug >= level) {
-		vfprintf(stderr,format,ap);
-	}
-	va_end(ap);
-}
\ No newline at end of file
+	va_start (ap,format);
+	if (debug >= level)
+		vfprintf (stderr,format,ap);
+	va_end (ap);
+}
