@@ -8,6 +8,6 @@ gint     dialog_promotion (void);
 gboolean dialog_login (gchar **user, gchar **pass);
 gboolean dialog_level (int *moves, int *level_time);
 void     dialog_prefs (void);
-void     dialog_pgn( Pgn_Tag *tag );
+Pgn_Tag *dialog_pgn( Pgn_Tag *tag );
 
 #endif /* GNOMECHESS_DIALOGS_H */
