@@ -26,21 +26,19 @@
 #include "dialogs.h"
 #include "makros.h"
 #include "pgn.h"
-#include "board-window.h"
 #include "engine-pgn.h"
 
-extern BoardWindow *main_board_window;
-
 static EngineClass *parent_class = NULL;
 
 static void class_init (EnginePgnClass *klass);
 static void init (EnginePgn *pgn);
+static void finalize (GObject *obj);
 
 static void game_selected_cb (GtkWidget *widget, int row, int column, GdkEventButton *event, gpointer user_data);
 
 static void column_clicked_cb (GtkWidget *widget, int column,  gpointer user_data);
 
-static void engine_local_fill_menu (EnginePgn *engine,GtkMenuShell *shell, gint pos);
+static void fill_menu (GtkMenuShell *shell, gint pos, gpointer data);
 
 struct _EnginePgnPrivate 
 {
@@ -50,47 +48,42 @@ struct _EnginePgnPrivate
 	GtkWidget *games;
 
 	pgn_info *pgn_info;
-	EngineInfo *info;
 	Pgn_Tag *tag;
 };
 
-GtkType
+GType
 engine_pgn_get_type (void)
 {
-  static GtkType type = 0;
+	static GType type = 0;
 
-  if (type == 0)
-    {
-      static const GtkTypeInfo info =
-      {
-        "EnginePgn",
-        sizeof (EnginePgn),
-        sizeof (EnginePgnClass),
-        (GtkClassInitFunc) class_init,
-        (GtkObjectInitFunc) init,
-        /* reserved_1 */ NULL,
-        /* reserved_2 */ NULL,
-        (GtkClassInitFunc) NULL,
-      };
+	if (!type) {
+		static const GTypeInfo info = {
+			sizeof (EnginePgnClass),
+			NULL,
+			NULL,
+			(GClassInitFunc) class_init,
+			NULL,
+			NULL,
+			sizeof (EnginePgn),
+			0,
+			(GInstanceInitFunc) init
+		};
 
-      type = gtk_type_unique (engine_get_type (), &info);
-    }
+		type = g_type_register_static (TYPE_ENGINE, "EnginePgn", &info, 0);
+	}
 
-  return type;
+	return type;
 }
 
 static void
 class_init (EnginePgnClass *klass)
 {
-	GtkObjectClass *object_class;
-	EngineClass *engine_class;
+	GObjectClass *object_class;
 
-	object_class = GTK_OBJECT_CLASS (klass);
-	engine_class = ENGINE_CLASS (klass);
+	object_class = G_OBJECT_CLASS (klass);
+	parent_class = g_type_class_peek_parent (klass);
 
-	parent_class = gtk_type_class (engine_get_type ());
-
-	engine_class->engine_fill_menu = (EngineFillMenu)engine_local_fill_menu;
+	object_class->finalize = finalize;	
 }
 
 
@@ -105,8 +98,6 @@ init (EnginePgn *engine)
 
 	engine->priv = priv;
 
-	priv->info = g_new0 (EngineInfo, 1);
-	
 	priv->sw = gtk_scrolled_window_new (NULL, NULL);
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (priv->sw),
 					GTK_POLICY_AUTOMATIC,     
@@ -127,40 +118,57 @@ init (EnginePgn *engine)
 	
 	gtk_container_add (GTK_CONTAINER (priv->sw), priv->games);
 
-	priv->view = game_view_new_with_engine (ENGINE (engine));
-	board_window_add_view (main_board_window, GAME_VIEW (priv->view));
+	priv->view = game_view_new (fill_menu, engine);
+	engine_view_add_game_view (engine_get_engine_view (ENGINE (engine)), GAME_VIEW (priv->view));
+}
+
+static void
+finalize (GObject *obj)
+{
+	EnginePgn *pgn = ENGINE_PGN (obj);
+	EnginePgnPrivate *priv;
+
+	priv = pgn->priv;
+	
+	g_free (priv);
+	pgn->priv = NULL;
+	
+	G_OBJECT_CLASS (parent_class)->finalize (obj);
 }
 
 
 
-GtkObject *
-engine_pgn_new (char *filename)
+GObject *
+engine_pgn_new (const char *filename)
 {
 	EnginePgn *engine;
 	EnginePgnPrivate *priv;
 	GList *l;
-	
-	engine = gtk_type_new (engine_pgn_get_type ());
+
+	engine = g_object_new (ENGINE_TYPE_PGN, NULL);
 	priv = engine->priv;
 	
 	priv->pgn_info = pgn_open (filename);
 
-	for (l = priv->pgn_info->game_tags; l != NULL; l = l->next) {
-		Pgn_Tag *tag = l->data;
-		char *text[3] = { "", "","" };
-		gint row;
+	if (priv->pgn_info) {
+		for (l = priv->pgn_info->game_tags; l != NULL; l = l->next) {
+			Pgn_Tag *tag = l->data;
+			char *text[3] = { "", "","" };
+			gint row;
 		
-		row = gtk_clist_append (GTK_CLIST (priv->games), text);
-		gtk_clist_set_row_data(GTK_CLIST (priv->games), row, (gpointer)row);
-		gtk_clist_set_text (GTK_CLIST (priv->games), row , 0, tag->white);
-		gtk_clist_set_text (GTK_CLIST (priv->games), row , 1, tag->black);
-		gtk_clist_set_text (GTK_CLIST (priv->games), row , 2, tag->result);
+			row = gtk_clist_append (GTK_CLIST (priv->games), text);
+			gtk_clist_set_row_data(GTK_CLIST (priv->games), row, (gpointer)row);
+			gtk_clist_set_text (GTK_CLIST (priv->games), row , 0, tag->white);
+			gtk_clist_set_text (GTK_CLIST (priv->games), row , 1, tag->black);
+			gtk_clist_set_text (GTK_CLIST (priv->games), row , 2, tag->result);
+		}
 	}
-	board_window_add_info (main_board_window, g_basename (filename), priv->sw);
+	engine_view_add_info_view (engine_get_engine_view (ENGINE (engine)),
+				   g_basename (filename), priv->sw);
 
 	gtk_clist_columns_autosize(GTK_CLIST(priv->games));
 
-	return GTK_OBJECT (engine);
+	return G_OBJECT (engine);
 }
 
 static void
@@ -176,30 +184,24 @@ game_selected_cb (GtkWidget *widget, int row, int column, GdkEventButton *event,
 	priv = engine->priv;
 
 	pgn_select_game (priv->pgn_info, GAME_VIEW (priv->view), row);
-	move_list_move_end (game_view_get_movelist (GAME_VIEW (priv->view)));
+	move_list_move_end (MOVE_LIST (GAME_VIEW (priv->view)->movelist));
 
 	priv->tag = g_list_nth_data(priv->pgn_info->game_tags, row);
 
-	if (priv->info->white)
-		g_free (priv->info->white);
 	gtk_clist_get_text (GTK_CLIST (priv->games), row, 0, &text);
-	priv->info->white = g_strdup (text);
+	game_view_set_white (GAME_VIEW (priv->view), text);
 	
-	if (priv->info->black)
-		g_free (priv->info->black);
 	gtk_clist_get_text (GTK_CLIST (priv->games), row, 1, &text);
-	priv->info->black = g_strdup (text);
+	game_view_set_black (GAME_VIEW (priv->view), text);
 	
 	gtk_clist_get_text (GTK_CLIST (priv->games), row, 2, &text);
 	
 	if (!strcmp (text, "1-0"))
-		priv->info->result = GAME_WHITE;
+		game_view_set_status (GAME_VIEW (priv->view), GAME_VIEW_STATUS_WHITE);
 	else if (!strcmp (text, "0-1"))
-		priv->info->result = GAME_BLACK;
+		game_view_set_status (GAME_VIEW (priv->view), GAME_VIEW_STATUS_BLACK);
 	else if (!strcmp (text, "1/2-1/2"))
-		priv->info->result = GAME_DRAW;
-		
-	gtk_signal_emit_by_name (GTK_OBJECT (engine), "info", priv->info);
+		game_view_set_status (GAME_VIEW (priv->view), GAME_VIEW_STATUS_DRAW);
 }
 
 static void
@@ -227,13 +229,13 @@ el_info (GtkWidget *widget, gpointer data)
 	EnginePgn *engine = data;
 
 	priv = engine->priv;
-	dialog_pgn(priv->tag);
+	priv->tag = dialog_pgn(priv->tag);
 }
 
 static void 
-engine_local_fill_menu (EnginePgn *engine, GtkMenuShell *shell, gint pos) 
+fill_menu (GtkMenuShell *shell, gint pos, gpointer data) 
 {
-	
+	Engine *engine = data;
 
 	GnomeUIInfo el_menu[] = 
 	{
@@ -244,7 +246,7 @@ engine_local_fill_menu (EnginePgn *engine, GtkMenuShell *shell, gint pos)
 	};
 
 	
-	gnome_app_fill_menu (shell, el_menu, gtk_accel_group_get_default (), TRUE, pos);
+	gnome_app_fill_menu (shell, el_menu, NULL, TRUE, pos);
 	
 
 }
