@@ -28,80 +28,55 @@
 #include <gtk/gtk.h>
 #include "makros.h"
 #include "position.h"
+#include "engine-view.h"
 
-#ifdef __cplusplus
-extern "C" {
-#pragma }
-#endif /* __cplusplus */
+G_BEGIN_DECLS
 
-#define TYPE_ENGINE			(engine_get_type ())
-#define ENGINE(obj)			(GTK_CHECK_CAST ((obj), TYPE_ENGINE, Engine))
-#define ENGINE_CLASS(klass)		(GTK_CHECK_CLASS_CAST ((klass), TYPE_ENGINE, EngineClass))
-#define IS_ENGINE(obj)			(GTK_CHECK_TYPE ((obj), TYPE_ENGINE))
-#define IS_ENGINE_CLASS(klass)		(GTK_CHECK_CLASS_TYPE ((obj), TYPE_ENGINE))
+#define TYPE_ENGINE	       (engine_get_type ())
+#define ENGINE(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_ENGINE, Engine))
+#define ENGINE_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_ENGINE, EngineClass))
+#define IS_ENGINE(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_ENGINE))
+#define IS_ENGINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_ENGINE))
 
 
 typedef struct _Engine        Engine;
 typedef struct _EnginePrivate EnginePrivate;
 typedef struct _EngineClass   EngineClass;
 
-typedef struct {
-	gchar *white;
-	gchar *black;
-	gint white_time;
-	gint black_time;
-	gint tomove;
-	GameResult result;
-	gchar *description;
-} EngineInfo;
-
 typedef enum {
 	ENGINE_ERROR_WARNING,
 	ENGINE_ERROR_CRITICAL
 } EngineError;
 
 typedef void (*EngineFillMenu) (Engine *, GtkMenuShell *, gint pos);
-typedef void (*EngineMove)     (Engine *, Square from, Square to);
-typedef void (*EngineExpire)   (Engine *, gshort color);
 
 struct _Engine {
-	GtkObject parent;
+	GObject parent;
 
 	EnginePrivate *priv;
 };
 
 struct _EngineClass {
-	GtkObjectClass parent_class;
+	GObjectClass parent_class;
 
 	/* Virtual functions */
 	EngineFillMenu engine_fill_menu;
-	EngineMove     engine_move;
-	EngineExpire   engine_expire;
 	
 	/* Signal prototypes */
 	void       (*game)   (Engine *engine, gint ply, Position *pos);
 	void       (*move)   (Engine *engine, Square from, Square to);
 	void       (*unmove) (Engine *engine, guint ply);
-	void       (*info)   (Engine *engine, EngineInfo *info);
 	void       (*error)  (Engine *engine, EngineError error);
 };
 
 
 
-GtkType      engine_get_type         (void);
-GtkObject   *engine_new              (void);
+GType engine_get_type  (void);
+EngineView  *engine_get_engine_view (Engine *engine);
+void  engine_fill_menu (Engine       *engine,
+			GtkMenuShell *shell,
+			gint          pos);
 
-void         engine_fill_menu        (Engine       *engine,
-				      GtkMenuShell *shell,
-				      gint          pos);
-void         engine_move             (Engine       *engine,
-				      Square        from,
-				      Square        to);
-void         engine_expire           (Engine       *engine,
-				      gshort        color);
+G_END_DECLS
 
-#ifdef __cplusplus
-}
-#endif /* __cplusplus */
-
-#endif /* _ENGINE_H_ */
+#endif
