@@ -30,7 +30,8 @@
 #include "prefs.h"
 #include "child.h"
 #include "notation.h"
-#include "board-window.h"
+#include "board.h"
+#include "clock.h"
 #include "dialogs.h"
 #include "server-term.h"
 #include "engine_null.h"
@@ -38,9 +39,9 @@
 
 /* Structs for game info */
 typedef struct {
-	EngineInfo info;
 	Engine *engine;
 	int game;
+	int rel;	
 	int ply;
 	gshort color;
 	gboolean flag;
@@ -50,6 +51,8 @@ struct _EngineIcsPrivate
 {
 	/* Server terminal */
 	ServerTerm *term;
+	int last_column_size;
+	int last_row_size;
 	
 	/* User info & status */
 	char *user;
@@ -99,13 +102,12 @@ static GIOChannel *chan = NULL;
 static gboolean have_read = FALSE;
 G_LOCK_DEFINE (ICS_INPUT);
 
-extern BoardWindow *main_board_window;
-
-static EngineClass *parent_class = NULL;
+static GObject *parent_class = NULL;
 
 static void class_init (EngineIcsClass *klass);
 static void init (EngineIcs *ics);
-static void destroy (GtkObject *obj);
+static void dispose (GObject *obj);
+static void finalize (GObject *obj);
 
 static GameView *ei_add_view (EngineIcs *engine);
 static void ei_view_cb (GtkWidget *widget, gpointer data);
@@ -118,40 +120,40 @@ static void ei_command_cb (GtkWidget *widget, gchar *command, gpointer data);
 extern int yylex (EngineIcs *engine);
 void yyerror (char *s);
 
-GtkType
+GType
 engine_ics_get_type (void)
 {
-  static GtkType type = 0;
+	static GType type = 0;
 
-  if (type == 0)
-    {
-      static const GtkTypeInfo info =
-      {
-        "EngineIcs",
-        sizeof (EngineIcs),
-        sizeof (EngineIcsClass),
-        (GtkClassInitFunc) class_init,
-        (GtkObjectInitFunc) init,
-        /* reserved_1 */ NULL,
-        /* reserved_2 */ NULL,
-        (GtkClassInitFunc) NULL,
-      };
+	if (!type) {
+		static const GTypeInfo info = {
+			sizeof (EngineIcsClass),
+			NULL,
+			NULL,
+			(GClassInitFunc) class_init,
+			NULL,
+			NULL,
+			sizeof (EngineIcs),
+			0,
+			(GInstanceInitFunc) init
+		};
 
-      type = gtk_type_unique (engine_get_type (), &info);
-    }
+		type = g_type_register_static (TYPE_ENGINE, "EngineIcs", &info, 0);
+	}
 
-  return type;
+	return type;
 }
 
 static void
 class_init (EngineIcsClass *klass)
 {
-	GtkObjectClass *object_class;
+	GObjectClass *object_class;
 	
-	object_class = GTK_OBJECT_CLASS (klass);
-	parent_class = gtk_type_class (engine_get_type ());
+	object_class = G_OBJECT_CLASS (klass);
+	parent_class = g_type_class_peek_parent (klass);
 
-	object_class->destroy = destroy;
+	object_class->dispose = dispose;
+	object_class->finalize = finalize;
 }
 
 
@@ -179,9 +181,48 @@ init (EngineIcs *engine)
 	priv->list = NULL;
 }
 
+static void
+dispose (GObject *obj)
+{
+	EngineIcs *engine;
+	EngineIcsPrivate *priv;
+
+	engine = ENGINE_ICS (obj);
+	priv = engine->priv;
+
+	g_source_remove (priv->read_cb);
+	g_source_remove (priv->err_cb);
+
+	g_io_channel_close (priv->read_chan);
+	g_io_channel_unref (priv->read_chan);
+
+	g_io_channel_close (priv->write_chan);
+	g_io_channel_unref (priv->write_chan);
+
+	stop_child (priv->childpid);
+
+	engine_view_remove_all_game_views (engine_get_engine_view (ENGINE (engine)));
+	
+	G_OBJECT_CLASS (parent_class)->dispose (obj);
+}
+
+static void
+finalize (GObject *obj)
+{
+	EngineIcs *engine;
+	EngineIcsPrivate *priv;
+	
+	engine = ENGINE_ICS (obj);
+	priv = engine->priv;
+
+	g_free (priv);
+	
+	G_OBJECT_CLASS (parent_class)->finalize (obj);
+}
+
 
 
-GtkObject *
+GObject *
 engine_ics_new (const char *host, 
 		const char *port, 
 		const char *user,
@@ -195,7 +236,7 @@ engine_ics_new (const char *host,
 	char *host_addr;
 	char *arg[4];
 	
-	engine = gtk_type_new (engine_ics_get_type ());
+	engine = g_object_new (ENGINE_TYPE_ICS, NULL);
 	priv = engine->priv;
 	
 	/* Set up the user/pass stuff */
@@ -212,6 +253,12 @@ engine_ics_new (const char *host,
 		arg[0] = g_strdup (telnetprogram);
 	
 	he = gethostbyname (host);
+
+	if (he == NULL) { /* name lookup failed, bail out */
+		herror(NULL); /* FIXME Dialog Box needed */
+		return NULL;
+	}
+
 	if (he->h_addr_list[0] != NULL) {
 		host_addr = g_strdup_printf ("%d.%d.%d.%d", 
 					     (guchar)he->h_addr_list[0][0],
@@ -228,7 +275,7 @@ engine_ics_new (const char *host,
 	arg[3] = NULL;
 		
 	/* Start the child process */
-	start_child (arg[0], arg,
+	start_child (arg,
 		     &priv->read_chan,
 		     &priv->write_chan,
 		     &priv->childpid);
@@ -243,10 +290,10 @@ engine_ics_new (const char *host,
 	g_free (arg[2]);
 	
 	view = ei_add_view (engine);
-	board_window_add_info (main_board_window, host, 
-			       GTK_WIDGET (priv->term));
+	engine_view_add_info_view (engine_get_engine_view (ENGINE (engine)), 
+				   host, GTK_WIDGET (priv->term));
 	
-	return GTK_OBJECT (engine);
+	return G_OBJECT (engine);
 }
 
 static void
@@ -261,8 +308,15 @@ ei_resize (EngineIcs *engine)
 		return;
 	
 	server_term_get_size (priv->term, &width, &height);
-	write_child (priv->write_chan, "set width %d\n", width);
-	write_child (priv->write_chan, "set height %d\n", height);
+	if (width != priv->last_column_size) {
+		write_child (priv->write_chan, "set width %d\n", width);
+		priv->last_column_size = width;
+	}
+
+	if (height != priv->last_row_size) {
+		write_child (priv->write_chan, "set height %d\n", height);
+		priv->last_row_size = height;
+	}
 }
 
 static void
@@ -314,9 +368,10 @@ ei_menu_rematch (GtkWidget *widget, gpointer data)
 }
 
 static void 
-engine_ics_fill_menu (EngineNull *enull, GtkMenuShell *shell, gint pos) 
+fill_menu (GtkMenuShell *shell, gint pos, gpointer data) 
 {
-	Engine *engine = gtk_object_get_data (GTK_OBJECT (enull), "ics");
+	ICSEngineInfo *icsinfo = data;
+	Engine *engine = icsinfo->engine;
 
 	GnomeUIInfo ei_menu[] = {
 
@@ -342,7 +397,7 @@ engine_ics_fill_menu (EngineNull *enull, GtkMenuShell *shell, gint pos)
 		GNOMEUIINFO_END
 	};
 
-	gnome_app_fill_menu (shell, ei_menu, gtk_accel_group_get_default (), TRUE, pos);
+	gnome_app_fill_menu (shell, ei_menu, NULL, TRUE, pos);
 }
 
 static ICSEngineInfo *
@@ -351,51 +406,25 @@ ei_get_info (GameView *view)
 	return gtk_object_get_data (GTK_OBJECT (view), "gameinfo");
 }
 
-static ICSEngineInfo *
-ei_get_info_from_enull (EngineIcs *engine, EngineNull *enull)
-{
-	EngineIcsPrivate *priv;
-	GList *l;
-	
-	priv = engine->priv;
-	
-	for (l = priv->list; l != NULL; l = l->next) {
-		GameView *view = GAME_VIEW (l->data);
-		ICSEngineInfo *info  = ei_get_info (view);
-
-		if (info->engine == ENGINE (enull))
-			return gtk_object_get_data (GTK_OBJECT (view), 
-						    "gameinfo");
-	}	
-
-	return NULL;
-}
-
 static void
 ei_init_info (ICSEngineInfo *info) 
 {
-	g_free (info->info.white);
-	g_free (info->info.black);
-	g_free (info->info.description);
-	
-	info->info.white = NULL;
-	info->info.black = NULL;
-	info->info.description = g_strdup ("New board");
-
 	info->game = 0;
+	info->rel = 0;	
 	info->ply  = 0;
 	info->color = NONE;
 	info->flag = FALSE;
 }
 
 static void 
-engine_ics_move (EngineNull *enull, Square from, Square to)
+board_move_cb (GtkWidget *widget, Square from, Square to, gpointer data)
 {
 	EngineIcs *engine;
 	EngineIcsPrivate *priv;
+	ICSEngineInfo *icsinfo = data;
 	char str[100];
 
-	engine = gtk_object_get_data (GTK_OBJECT (enull), "ics");
+	engine = ENGINE_ICS (icsinfo->engine);
 	priv = engine->priv;
 
 	move_to_ascii (str, from, to);
@@ -403,17 +432,32 @@ engine_ics_move (EngineNull *enull, Square from, Square to)
 }
 
 static void
-engine_ics_expire (EngineNull *enull, gshort color)
+white_expired_cb (GtkWidget *widget, gpointer data)
 {
 	EngineIcs *engine;
 	EngineIcsPrivate *priv;
-	ICSEngineInfo *icsinfo;
-	
-	engine = gtk_object_get_data (GTK_OBJECT (enull), "ics");
+	ICSEngineInfo *icsinfo = data;
+
+	engine = ENGINE_ICS (icsinfo->engine);
 	priv = engine->priv;
 
-	icsinfo = ei_get_info_from_enull (engine, enull);
-	if (icsinfo->flag && icsinfo->color != color && prefs_get_autoflag ()) {
+	if (icsinfo->flag && icsinfo->color != WHITE && prefs_get_autoflag ()) {
+		debug_print (DEBUG_NORMAL, "Autoflagging\n");
+		write_child (priv->write_chan, "flag\n");
+	}
+}
+
+static void
+black_expired_cb (GtkWidget *widget, gpointer data)
+{
+	EngineIcs *engine;
+	EngineIcsPrivate *priv;
+	ICSEngineInfo *icsinfo = data;
+
+	engine = ENGINE_ICS (icsinfo->engine);
+	priv = engine->priv;
+
+	if (icsinfo->flag && icsinfo->color != BLACK && prefs_get_autoflag ()) {
 		debug_print (DEBUG_NORMAL, "Autoflagging\n");
 		write_child (priv->write_chan, "flag\n");
 	}
@@ -430,21 +474,22 @@ ei_add_view (EngineIcs *engine)
 	
 	info = g_new0 (ICSEngineInfo, 1);
 	ei_init_info (info);
-	info->engine = ENGINE (engine_null_new ());
-
-	/* Null engine needs info to handle callbacks */
-	engine_null_set_fill_menu (ENGINE_NULL (info->engine), 
-				   (EngineFillMenu) engine_ics_fill_menu);
-	engine_null_set_move (ENGINE_NULL (info->engine),
-			      (EngineMove) engine_ics_move);
-	engine_null_set_expire (ENGINE_NULL (info->engine),
-				(EngineExpire) engine_ics_expire);
-
-	gtk_object_set_data (GTK_OBJECT (info->engine), "ics", engine);
-
+	info->engine = ENGINE (engine);
+	
 	/* Build a new board window */
-	view = game_view_new_with_engine (info->engine);
-	board_window_add_view (main_board_window, GAME_VIEW (view));
+	view = game_view_new (fill_menu, info);
+
+	board_set_white_lock (BOARD (GAME_VIEW (view)->board), BOARD_LOCK_COMPLETE);
+	board_set_black_lock (BOARD (GAME_VIEW (view)->board), BOARD_LOCK_COMPLETE);
+
+	g_signal_connect (G_OBJECT (GAME_VIEW (view)->board), "move",
+			  G_CALLBACK (board_move_cb), info);
+	g_signal_connect (G_OBJECT (GAME_VIEW (view)->white_clock), "expired",
+			  G_CALLBACK (white_expired_cb), info);
+	g_signal_connect (G_OBJECT (GAME_VIEW (view)->black_clock), "expired",
+			  G_CALLBACK (black_expired_cb), info);
+	
+	engine_view_add_game_view (engine_get_engine_view (ENGINE (engine)), GAME_VIEW (view));
 
 	gtk_object_set_data (GTK_OBJECT (view), "gameinfo", info);
 
@@ -458,7 +503,7 @@ ei_add_view (EngineIcs *engine)
 }
 
 static GameView *
-ei_get_view (EngineIcs *engine, int game)
+ei_get_view (EngineIcs *engine, int game, gboolean create_view)
 {
 	EngineIcsPrivate *priv;
 	GameView *view, *alt_view = NULL;
@@ -475,7 +520,7 @@ ei_get_view (EngineIcs *engine, int game)
 			return view;
 		else if (info->game == 0)
 			alt_view = view;
-	}	
+	}
 
 	if (alt_view != NULL) {
 		ICSEngineInfo *info;
@@ -485,8 +530,11 @@ ei_get_view (EngineIcs *engine, int game)
 
 		return alt_view;
 	}
-	
-	return ei_add_view (engine);
+
+	if (create_view)
+		return ei_add_view (engine);
+
+	return NULL;	
 }
 
 void
@@ -557,7 +605,8 @@ engine_ics_result (EngineIcs *engine, char *result)
 	GameView *view;
 	ICSEngineInfo *icsinfo;
 	char *rstr;
-	gint resultval, game;
+	GameViewStatus status;
+	gint game;
 
 	/* Figure out what game */
 	rstr = strchr (result, ' ');
@@ -568,24 +617,24 @@ engine_ics_result (EngineIcs *engine, char *result)
 	rstr = strrchr(result, ' ');
 	rstr++;
 	if (!strcmp (rstr, "1-0"))
-		resultval = GAME_WHITE;
+		status = GAME_VIEW_STATUS_WHITE;
 	else if (!strcmp (rstr, "0-1"))
-		resultval = GAME_BLACK;
+		status = GAME_VIEW_STATUS_BLACK;
 	else if (!strcmp (rstr, "1/2-1/2"))
-		resultval = GAME_DRAW;
+		status = GAME_VIEW_STATUS_DRAW;
 	else
-		resultval = GAME_ABORTED;
+		status = GAME_VIEW_STATUS_ABORTED;
 
 	/* Update the info struct */
-	view = ei_get_view (engine, game);
+	view = ei_get_view (engine, game, FALSE);
 
+	if (view == NULL)
+		return;
+	
 	icsinfo = ei_get_info (view);
 	icsinfo->game = 0;
-	icsinfo->info.result = resultval;
 
-	/* Signal the new info */
-	gtk_signal_emit_by_name (GTK_OBJECT (icsinfo->engine),
-				 "info", &(icsinfo->info));
+	game_view_set_status (view, status);
 }
 
 int 
@@ -606,13 +655,22 @@ engine_ics_input (char *buf, int max)
 }
 
 void 
-engine_ics_output (EngineIcs *engine, char *str) 
+engine_ics_output (EngineIcs *engine, char *str, int c_index) 
 {
 	EngineIcsPrivate *priv;
 	
 	priv = engine->priv;
 
+	debug_print (DEBUG_VERBOSE, "Engine Input: %s", str);
+	if (c_index >= 0) {
+		char *c_str = NULL;
+		
+		if (c_index <= 7)
+			c_str = g_strdup_printf ("\033[3%dm", c_index);
+		server_term_print (priv->term, c_str);
+	}
 	server_term_print (priv->term, str);
+	server_term_print (priv->term, "\033[39m");
 }
 
 static Position *
@@ -678,10 +736,9 @@ engine_ics_update_board (EngineIcs *engine, char *boardstring)
 {
 	EngineIcsPrivate *priv;
 	GameView *view;
-	Board *board;
 	Position *pos;
 	ICSEngineInfo *icsinfo;
-	gchar **tokens;
+	gchar **tokens, *description;
 	char b[65], m[10];
 	int game, colour, ply, rel;
 	Square from, to;
@@ -699,16 +756,46 @@ engine_ics_update_board (EngineIcs *engine, char *boardstring)
 	game = atoi (tokens[GAME]);
 
 	/* Get the board assigned to this engine */
-	view = ei_get_view (engine, game);
-	board = game_view_get_board (view);
-
+	view = ei_get_view (engine, game, TRUE);
 	icsinfo = ei_get_info (view);
+
+	/* Find out who is to move */ 
+	if (!strcmp (tokens[TO_MOVE], "W"))
+		colour = WHITE;
+	else
+		colour = BLACK;
 	
-	/* Find the user's relation to the game */
+	/* Find relation to the game and lock the board accordingly*/
 	rel = atoi (tokens[RELATION]);
-		
+	switch (rel) {
+	case -3:
+	case -2:
+	case 0:
+		board_set_white_lock (BOARD (view->board), BOARD_LOCK_COMPLETE);
+		board_set_black_lock (BOARD (view->board), BOARD_LOCK_COMPLETE);
+		break;
+	case -1:
+		board_set_white_lock (BOARD (view->board), 
+				      colour == WHITE ? BOARD_LOCK_COMPLETE : BOARD_LOCK_SELECT);
+		board_set_black_lock (BOARD (view->board), 
+				      colour == BLACK ? BOARD_LOCK_COMPLETE : BOARD_LOCK_SELECT);
+		break;
+	case 1:
+		board_set_white_lock (BOARD (view->board), 
+				      colour == WHITE ? BOARD_LOCK_NONE : BOARD_LOCK_COMPLETE);
+		board_set_black_lock (BOARD (view->board), 
+				      colour == BLACK ? BOARD_LOCK_NONE : BOARD_LOCK_COMPLETE);
+		break;
+	case 2:
+		board_set_white_lock (BOARD (view->board), 
+				      colour == WHITE ? BOARD_LOCK_NONE : BOARD_LOCK_COMPLETE);
+		board_set_black_lock (BOARD (view->board), 
+				      colour == BLACK ? BOARD_LOCK_NONE : BOARD_LOCK_COMPLETE);
+		break;
+	}
+	
 	/* Flip the board if necessary */ 
-	board_set_flip (board, atoi (tokens[FLIP]));
+	board_set_flip (BOARD (view->board), atoi (tokens[FLIP]));
 
 	/* Extract the board string */
 	b[0] = '\0';
@@ -733,13 +820,7 @@ engine_ics_update_board (EngineIcs *engine, char *boardstring)
 		}
 	} else {
 		strcpy (m, "none");
-	}
-	
-	/* Find out who is to move */ 
-	if (!strcmp (tokens[TO_MOVE], "W"))
-		colour = WHITE;
-	else
-		colour = BLACK;
+	}	
 		
 	/* Figure out what ply this is */
 	if (!strcmp (m, "none"))
@@ -749,32 +830,24 @@ engine_ics_update_board (EngineIcs *engine, char *boardstring)
 	else
 		ply = atoi (tokens [MOVE_NUM])*2-1;
 
-	/* Update the info structure */
-	if (!icsinfo->info.white ||
-	    !strcmp (icsinfo->info.white, tokens [WHITE_NAME]))
-		icsinfo->info.white = g_strdup (tokens [WHITE_NAME]);
-	if (!icsinfo->info.black ||
-	    !strcmp (icsinfo->info.black, tokens [BLACK_NAME]))
-		icsinfo->info.black = g_strdup (tokens [BLACK_NAME]);
+	/* Update the game view */
+	/* FIXME Only set once */
+	game_view_set_white (view, tokens [WHITE_NAME]);
+	game_view_set_black (view, tokens [BLACK_NAME]);
 
-	icsinfo->info.white_time = atoi (tokens [WHITE_TIME]);
-	icsinfo->info.black_time = atoi (tokens [BLACK_TIME]);
+	description = g_strdup_printf ("%s %s", tokens[START_TIME], tokens[START_INC]);
+	game_view_set_description (view, description);
+	g_free (description);
+	
+	clock_set_time (CLOCK (view->white_clock), atoi (tokens [WHITE_TIME]));
+	clock_set_time (CLOCK (view->black_clock), atoi (tokens [BLACK_TIME]));
 
-	icsinfo->info.tomove = colour;
+	game_view_set_to_move (view, colour);
 
 	if (rel >= -1 && rel <= 1)
-		icsinfo->info.result = GAME_PROGRESS;
+		game_view_set_status (view, GAME_VIEW_STATUS_PROGRESS);
 	else
-		icsinfo->info.result = GAME_NONE;
-	
-	if (icsinfo->info.description)
-		g_free (icsinfo->info.description);
-
-	icsinfo->info.description = g_strdup_printf ("%s %s game, %s to move ",
-						     tokens[START_TIME], 
-						     tokens[START_INC],
-						     colour == WHITE ? 
-						     "white" : "black");
+		game_view_set_status (view, GAME_VIEW_STATUS_NONE);
 	
 	icsinfo->flag = (rel == 1 || rel == -1) ? TRUE : FALSE;
 	if (rel == 1)
@@ -786,47 +859,25 @@ engine_ics_update_board (EngineIcs *engine, char *boardstring)
 
 	/* Setup the board and figure out the move if there */
 	/* was no dnd update or this is a different game */
-	pos = board_get_position (board);
+	pos = board_get_position (BOARD (view->board));
 	if (strcmp (m, "none") && ply - icsinfo->ply == 1) {
+		icsinfo->rel = rel;
 		icsinfo->ply = ply;
 		ascii_to_move (pos, m, &from, &to);
-		if (position_get_color_to_move (pos) != colour)
-			gtk_signal_emit_by_name (GTK_OBJECT (icsinfo->engine),
-						 "move", from, to);
+		if (position_get_color_to_move (pos) != colour) {
+				board_move (BOARD (view->board), from, to);
+				move_list_add (MOVE_LIST (view->movelist), from, to);
+		}
 	} else {
 		pos = engine_ics_board_to_pos (b);
 		position_set_color_to_move (pos, colour);
-		icsinfo->game = game;				
+		icsinfo->game = game;
+		icsinfo->rel = rel;		
 		icsinfo->ply = ply;
-		gtk_signal_emit_by_name (GTK_OBJECT (icsinfo->engine), 
-					 "game", ply, pos);
+		
+		board_set_position (BOARD (view->board), pos);
+		move_list_clear_initial (MOVE_LIST (view->movelist), ply, pos);
 	}
-	gtk_signal_emit_by_name (GTK_OBJECT (icsinfo->engine),
-				 "info", &(icsinfo->info));
-}
-
-static void
-destroy (GtkObject *obj)
-{
-	EngineIcs *engine;
-	EngineIcsPrivate *priv;
-	GList *l;
-
-	engine = ENGINE_ICS (obj);
-	priv = engine->priv;
-
-	g_io_channel_close (priv->read_chan);
-	g_io_channel_unref (priv->read_chan);
-
-	g_io_channel_close (priv->write_chan);
-	g_io_channel_unref (priv->write_chan);
-
-	/* Destroy the associated boards */
-	for (l = priv->list; l != NULL; l = l->next) {
-		gtk_object_destroy (GTK_OBJECT (l->data));
-	}
-
-	GTK_OBJECT_CLASS (parent_class)->destroy (obj);
 }
 
 static gboolean
@@ -834,11 +885,15 @@ ei_input_cb (GIOChannel *source,
 	     GIOCondition condition,
 	     gpointer data)
 {
+	EngineIcs *engine = data;
+	EngineIcsPrivate *priv;	
 	int token;
 
+	priv = engine->priv;
+	
 	G_LOCK (ICS_INPUT);
 	chan = source;
-	token = yylex (ENGINE_ICS (data));
+	token = yylex (engine);
 	G_UNLOCK (ICS_INPUT);
 	
 	return TRUE;
@@ -849,8 +904,7 @@ ei_err_cb (GIOChannel *source,
 	   GIOCondition condition,
 	   gpointer data)
 {
-	gtk_signal_emit_by_name (GTK_OBJECT (data), "error",
-				 ENGINE_ERROR_CRITICAL);
+	g_signal_emit_by_name (G_OBJECT (data), "error", ENGINE_ERROR_CRITICAL);
 
 	return FALSE;
 }
@@ -884,13 +938,12 @@ ei_view_cb (GtkWidget *widget, gpointer data)
 	engine = ENGINE_ICS (data);
 	priv = engine->priv;
 
-	elem = g_list_find (priv->list, widget);
+	elem = g_list_find (priv->list, widget);	
 	if (elem != NULL) {
-		/* Free the info */
 		info = ei_get_info (GAME_VIEW (widget));
-		gtk_object_remove_data (GTK_OBJECT (elem->data), "gameinfo");
 		g_free (info);
 		
 		priv->list = g_list_remove (priv->list, elem->data);
 	}
 }
+
