@@ -29,19 +29,20 @@
 #include "child.h"
 #include "notation.h"
 #include "dialogs.h"
-#include "board-window.h"
 #include "game-view.h"
+#include "board.h"
 #include "server-term.h"
 #include "engine_local.h"
 
 /* Prototypes */
 static void class_init (EngineLocalClass *klass);
 static void init (EngineLocal *engine);
+static void finalize (GObject *obj);
+static void dispose (GObject *obj);
 
-static void engine_local_fill_menu (EngineLocal *engine, GtkMenuShell *shell, gint pos);
-static void engine_local_move (EngineLocal *engine, Square from, Square to);
+static void fill_menu (GtkMenuShell *shell, gint pos, gpointer data);
+static void board_move_cb (GtkWidget *widget, Square from, Square to, gpointer data);
 static void el_write_position (EngineLocal *engine);
-static void engine_local_destroy (GtkObject *obj);
 
 static gboolean engine_local_cb     (GIOChannel *source,
 				     GIOCondition condition,
@@ -51,8 +52,6 @@ static gboolean engine_local_err_cb (GIOChannel *source,
 				     gpointer data);
 
 
-extern BoardWindow *main_board_window;
-
 struct _EngineLocalPrivate 
 {
 	GameView *view;
@@ -74,49 +73,46 @@ struct _EngineLocalPrivate
 	gint err_cb;
 };
 
-static GtkObjectClass *parent_class = NULL;
+static GObjectClass *parent_class = NULL;
 
 
-GtkType
+GType
 engine_local_get_type (void)
 {
-  static GtkType type = 0;
+	static GType type = 0;
 
-  if (type == 0)
-    {
-      static const GtkTypeInfo engine_local_info =
-      {
-        "EngineLocal",
-        sizeof (EngineLocal),
-        sizeof (EngineLocalClass),
-        (GtkClassInitFunc) class_init,
-        (GtkObjectInitFunc) init,
-        /* reserved_1 */ NULL,
-        /* reserved_2 */ NULL,
-        (GtkClassInitFunc) NULL,
-      };
+	if (!type) {
+		static const GTypeInfo info = {
+			sizeof (EngineLocalClass),
+			NULL,
+			NULL,
+			(GClassInitFunc) class_init,
+			NULL,
+			NULL,
+			sizeof (EngineLocal),
+			0,
+			(GInstanceInitFunc) init
+		};
 
-      type = gtk_type_unique (engine_get_type (), &engine_local_info);
-    }
+		type = g_type_register_static (TYPE_ENGINE, "EngineLocal", &info, 0);
+	}
 
-  return type;
+	return type;
 }
 
 static void
 class_init (EngineLocalClass *klass)
 {
-	GtkObjectClass *object_class;
+	GObjectClass *object_class;
 	EngineClass *engine_class;
 	
-	object_class = GTK_OBJECT_CLASS (klass);
+	object_class = G_OBJECT_CLASS (klass);
 	engine_class = ENGINE_CLASS (klass);
-	
-	parent_class = gtk_type_class (gtk_object_get_type ());
 
-	object_class->destroy = engine_local_destroy;
-	
-	engine_class->engine_fill_menu = (EngineFillMenu)engine_local_fill_menu;
-	engine_class->engine_move = (EngineMove)engine_local_move;
+	parent_class = g_type_class_peek_parent (klass);
+
+	object_class->dispose = dispose;
+	object_class->finalize = finalize;
 }
 
 
@@ -131,26 +127,71 @@ init (EngineLocal *local)
 
 	priv->computer = BLACK;
 
-	priv->view = GAME_VIEW (game_view_new_with_engine (ENGINE (local)));
-	board_window_add_view (main_board_window, GAME_VIEW (priv->view));
+	priv->view = GAME_VIEW (game_view_new (fill_menu, local));
+
+	board_set_white_lock (BOARD (priv->view->board), BOARD_LOCK_NONE);
+	board_set_black_lock (BOARD (priv->view->board), BOARD_LOCK_COMPLETE);
+
+	g_signal_connect (G_OBJECT (priv->view->board), "move",
+			  G_CALLBACK (board_move_cb), local);	
 
 	priv->analyse_info = SERVER_TERM (server_term_new ());
 	server_term_hide_prompt (priv->analyse_info);
 }
 
-
 
-GtkObject *
-engine_local_new (char *cmd, char **arg)
+static void
+dispose (GObject *obj) 
 {
 	EngineLocal *engine;
 	EngineLocalPrivate *priv;
 	
-	engine = gtk_type_new (ENGINE_TYPE_LOCAL);
+	engine = ENGINE_LOCAL (obj);
+	priv = engine->priv;
+
+	g_source_remove(priv->read_cb);
+	g_source_remove(priv->err_cb);
+	
+	g_io_channel_close (priv->read_chan);
+	g_io_channel_unref (priv->read_chan);
+
+	g_io_channel_close (priv->write_chan);
+	g_io_channel_unref (priv->write_chan);
+
+	stop_child (priv->childpid);
+	
+	G_OBJECT_CLASS (parent_class)->dispose (obj);
+}
+
+static void
+finalize (GObject *obj) 
+{
+	EngineLocal *engine;
+	EngineLocalPrivate *priv;
+	
+	engine = ENGINE_LOCAL (obj);
+	priv = engine->priv;
+
+	g_free (priv);
+	
+	G_OBJECT_CLASS (parent_class)->finalize (obj);
+}
+
+
+
+GObject *
+engine_local_new (char **arg)
+{
+	EngineLocal *engine;
+	EngineLocalPrivate *priv;
+
+	engine = g_object_new (ENGINE_TYPE_LOCAL, NULL);
 
 	priv = engine->priv;
-	
-	start_child (cmd, arg, &priv->read_chan,
+
+	engine_view_add_game_view (engine_get_engine_view (ENGINE (engine)), GAME_VIEW (priv->view));
+
+	start_child (arg, &priv->read_chan,
 		     &priv->write_chan, &priv->childpid);
 	
 	priv->read_cb = g_io_add_watch (priv->read_chan, G_IO_IN,
@@ -164,7 +205,7 @@ engine_local_new (char *cmd, char **arg)
 	write_child (priv->write_chan, "easy\n");
 	write_child (priv->write_chan, "level 60 2 0\n");
 
-	return GTK_OBJECT(engine);
+	return G_OBJECT (engine);
 }
 
 static void
@@ -177,8 +218,8 @@ show_analyse_info (EngineLocal *engine)
 	if (priv->analyse_info_added)
 		return;
 
-	board_window_add_info (main_board_window, "Analysis", 
-			       GTK_WIDGET (priv->analyse_info));
+	engine_view_add_info_view (engine_get_engine_view (ENGINE (engine)), 
+			       "Analysis", GTK_WIDGET (priv->analyse_info));
 	priv->analyse_info_added = TRUE;
 }
 
@@ -192,8 +233,8 @@ hide_analyse_info (EngineLocal *engine)
 	if (!priv->analyse_info_added)
 		return;
 
-	board_window_remove_info (main_board_window,
-				  GTK_WIDGET (priv->analyse_info));
+	engine_view_remove_info_view (engine_get_engine_view (ENGINE (engine)),
+				      GTK_WIDGET (priv->analyse_info));
 	priv->analyse_info_added = FALSE;
 	
 }
@@ -206,7 +247,7 @@ el_menu_set_color (EngineLocal *engine, gshort color)
 	Position *pos;
 	
 	priv = engine->priv;
-	board = game_view_get_board (priv->view);
+	board = BOARD (priv->view->board);
 
 	priv->computer = color;
 
@@ -321,16 +362,16 @@ el_menu_takeback (GtkWidget *widget, gpointer data)
 	engine = ENGINE_LOCAL (data);
 	priv = engine->priv;
 
-	board = game_view_get_board (priv->view);
+	board = BOARD(priv->view->board);
 	pos = board_get_position (board);
 	
 	if ((priv->computer == BLACK && position_get_color_to_move (pos) == WHITE) ||
 	    (priv->computer == WHITE && position_get_color_to_move (pos) == BLACK)) {
 		write_child (priv->write_chan, "remove\n");
-		gtk_signal_emit_by_name (GTK_OBJECT (engine), "unmove", 2);
+		g_signal_emit_by_name (G_OBJECT (engine), "unmove", 2);
 	} else {
 		write_child (priv->write_chan, "undo\n");
-		gtk_signal_emit_by_name (GTK_OBJECT (engine), "unmove", 1);
+		g_signal_emit_by_name (G_OBJECT (engine), "unmove", 1);
 	}
 }
 
@@ -347,8 +388,9 @@ el_menu_now (GtkWidget *widget, gpointer data)
 }
 
 static void 
-engine_local_fill_menu (EngineLocal *engine, GtkMenuShell *shell, gint pos) 
+fill_menu (GtkMenuShell *shell, gint pos, gpointer data) 
 {
+	EngineLocal *engine = data;
 	EngineLocalPrivate *priv;
 	
 	GnomeUIInfo options_mode_items[] =
@@ -396,7 +438,7 @@ engine_local_fill_menu (EngineLocal *engine, GtkMenuShell *shell, gint pos)
 
 	priv = engine->priv;
 	
-	gnome_app_fill_menu (shell, el_menu, gtk_accel_group_get_default (), TRUE, pos);
+	gnome_app_fill_menu (shell, el_menu, NULL, TRUE, pos);
 	
 	priv->whitecb = options_mode_items[0].widget;
 	priv->blackcb = options_mode_items[1].widget;
@@ -406,15 +448,16 @@ engine_local_fill_menu (EngineLocal *engine, GtkMenuShell *shell, gint pos)
 }
 
 static void 
-engine_local_move (EngineLocal *engine, Square from, Square to)
+board_move_cb (GtkWidget *widget, Square from, Square to, gpointer data)
 {
+	EngineLocal *engine = data;
 	EngineLocalPrivate *priv;
 	MoveList *move_list;
 	char str[100];
 
 	priv = engine->priv;
 	
-	move_list = game_view_get_movelist (priv->view);
+	move_list = MOVE_LIST (priv->view->movelist);
 	if (move_list_currply (move_list) < move_list_maxply (move_list)) {
 		move_list_clear_from (move_list, move_list_currply (move_list));
 		el_write_position (engine);
@@ -436,13 +479,14 @@ el_process_move (EngineLocal *engine, char *p)
 
 	priv = engine->priv;
 
-	position = board_get_position (game_view_get_board (priv->view));
+	position = board_get_position (BOARD (priv->view->board));
 	if (san_to_move (position, p, &from, &to))
 		ascii_to_move (position, p, &from, &to);
 
-
 	debug_print (DEBUG_NORMAL, "Move detected: %s %d %d\n", p+4, from, to);
-	gtk_signal_emit_by_name (GTK_OBJECT (engine), "move", from, to);
+
+	board_move (BOARD (priv->view->board), from, to);
+	move_list_add (MOVE_LIST (priv->view->movelist), from, to);
 }
 
 static void 
@@ -457,7 +501,7 @@ el_write_position (EngineLocal *engine)
 
 	priv = engine->priv;
 	
-	board = game_view_get_board (priv->view);
+	board = BOARD (priv->view->board);
 	pos = board_get_position (board);
 	
 	write_child (priv->write_chan, "edit\n");
@@ -507,26 +551,6 @@ el_write_position (EngineLocal *engine)
 	write_child (priv->write_chan, ".\n");
 }
 
-static void
-engine_local_destroy (GtkObject *obj) 
-{
-	EngineLocal *engine;
-	EngineLocalPrivate *priv;
-	
-	engine = ENGINE_LOCAL (obj);
-	priv = engine->priv;
-	
-	g_io_channel_close (priv->read_chan);
-	g_io_channel_unref (priv->read_chan);
-
-	g_io_channel_close (priv->write_chan);
-	g_io_channel_unref (priv->write_chan);
-
-	stop_child (priv->childpid);
-	
-	GTK_OBJECT_CLASS (parent_class)->destroy (obj);
-}
-
 static gboolean
 engine_local_cb (GIOChannel *source,
 		 GIOCondition condition,
@@ -587,10 +611,12 @@ engine_local_err_cb (GIOChannel *source,
 		     gpointer data)
 {
 	EngineLocal *engine;
-
+	GtkWidget *dlg;
+	
 	engine = ENGINE_LOCAL(data);
 
-	g_error ("Local Engine connection died");
+	dlg = gnome_warning_dialog(_("Local Engine connection died"));
+	gnome_dialog_run_and_close (GNOME_DIALOG (dlg));
 	
 	return FALSE;
 }
