@@ -26,10 +26,8 @@
 #include "debug.h"
 #include "makros.h"
 #include "prefs.h"
-#include "engine_local.h"
-#include "engine_ics.h"
-#include "engine-pgn.h"
-#include "board-window.h"
+#include "engine-window-registry.h"
+#include "engine-window.h"
  
 /* Command line variables */
 static gint *ics = 0;
@@ -64,53 +62,63 @@ static const struct poptOption gnome_chess_popt_options [] = {
 	{ NULL, '\0', 0, NULL, 0 }
 };
 
-GtkWidget *main_board_window = NULL;
+GtkWidget *main_engine_window = NULL;
 
 int 
 main (int argc, char *argv []) 
 {
-	GtkObject *engine;
-	GtkWidget *view;
 	int i = 0;
 	
-	/* Internationalization */
-	bindtextdomain (PACKAGE, GNOMELOCALEDIR);
-	textdomain (PACKAGE);
+	bindtextdomain (GETTEXT_PACKAGE, GNOME_CHESS_LOCALEDIR);
+	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 
 	/* Command Line Args */
-	gnome_init_with_popt_table ("Gnome Chess", 
+	gnome_init_with_popt_table (PACKAGE, 
 				    VERSION, 
 				    argc, argv, 
 				    gnome_chess_popt_options,
 				    0, &ctx);
 
-#ifdef USE_WM_ICONS
 	gnome_window_icon_set_default_from_file (GNOME_ICONDIR 
 						 "/gnome-chess.png");
-#endif
+
 	/* Initialize the preferences */
 	prefs_init();
 
 	/* Initialize glade */
 	glade_gnome_init();
+	
+	/* A Board Window */
+	main_engine_window = engine_window_new ();
+	engine_window_registry_add (ENGINE_WINDOW (main_engine_window));
+	gtk_window_set_default_size (GTK_WINDOW (main_engine_window), 560, 420);
+	gtk_widget_show (main_engine_window);
 
-	main_board_window = board_window_new ();
-	gtk_widget_show (main_board_window);
-
+	/* Process various command line options */
 	if (fcp != NULL) {
-		engine = engine_local_new (fcp, NULL);
-		view = game_view_new_with_engine (ENGINE (engine));
-		board_window_add_view (BOARD_WINDOW (main_board_window), 
-				       GAME_VIEW (view));
+		char *argv[2];
+		
+		argv[0] = fcp;
+		argv[1] = NULL;
+		
+		engine_window_add_local_engine (ENGINE_WINDOW (main_engine_window), argv);
 	}
 
-	if (ics && icshost != NULL)
-		engine = engine_ics_new (icshost, icsport, icsuser, icspass, NULL);
-
+	if (ics && icshost != NULL) {
+		engine_window_add_ics_engine (ENGINE_WINDOW (main_engine_window),
+					      icshost, icsport, icsuser, icspass, NULL);
+	}
+	
 	/* open the files */
 	startup_files = (char **)poptGetArgs (ctx);
-	for (i = 0; startup_files && startup_files[i]; i++)
-		engine_pgn_new (startup_files[i]);
+	for (i = 0; startup_files && startup_files[i]; i++) {
+		engine_window_add_pgn_engine (ENGINE_WINDOW (main_engine_window), startup_files[i]);
+	}
+	
+	/* If nothing else is open, show a board */
+	if (engine_window_engine_count (ENGINE_WINDOW (main_engine_window)) == 0)
+		engine_window_add_null_engine (ENGINE_WINDOW (main_engine_window));
+
 	poptFreeContext (ctx);
 	
 	/* Begin the event loop */
