@@ -115,12 +115,10 @@ class_init (MoveListClass *klass)
 
 	move_list_signals[MOVE_SIGNAL] = gtk_signal_new ("move",
 							GTK_RUN_FIRST,
-							object_class->type,
+							GTK_CLASS_TYPE (object_class),
 							GTK_SIGNAL_OFFSET (MoveListClass, move_selected),
 							gtk_marshal_NONE__INT, 
 							GTK_TYPE_NONE, 1, GTK_TYPE_INT);
-
-         gtk_object_class_add_signals (object_class, move_list_signals, LAST_SIGNAL);
 }
 
 
@@ -144,7 +142,9 @@ init (MoveList *movelist)
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (priv->swindow),
 					GTK_POLICY_AUTOMATIC, 
 					GTK_POLICY_ALWAYS);
-	gtk_widget_set_usize (GTK_WIDGET (priv->swindow), 200, PIECE_SIZE * 8);
+
+	gtk_widget_set_usize (GTK_WIDGET (priv->swindow), 200, 0);
+
 	gtk_container_add (GTK_CONTAINER (movelist), priv->swindow);
 	gtk_widget_show (priv->swindow);
 
@@ -161,7 +161,8 @@ init (MoveList *movelist)
 	for (i = 0; i < 3; i++)
 		gtk_clist_set_column_width (GTK_CLIST (clist), i, 50);
 
-	gtk_widget_set_usize (clist, 150, PIECE_SIZE * 8 );
+	gtk_widget_set_usize (clist, 150, 0 );
+
 	gtk_container_add (GTK_CONTAINER (priv->swindow), clist);
 	gtk_widget_show (clist);
 	priv->clist = clist;
@@ -174,7 +175,7 @@ init (MoveList *movelist)
 		
 		full = g_strdup_printf ("%s/pixmaps/gnome-chess/%s", 
 					GNOMEDATADIR, fn[i]);
-		pb = gdk_pixbuf_new_from_file (full);
+		pb = gdk_pixbuf_new_from_file (full, NULL);
 		if (pb != NULL) {
 			GtkWidget *btn, *gtp;
 			GdkPixmap *gdp;
@@ -360,6 +361,11 @@ move_list_add (MoveList *movelist, Square from, Square to)
 	g_return_if_fail (IS_MOVE_LIST (movelist));
 
 	priv = movelist->priv;
+
+	if ( move_list_currply(movelist) < move_list_maxply(movelist)) 
+	{
+		move_list_clear_from (movelist, move_list_currply(movelist));
+	}
 	
 	p = g_new (Ply, 1);
 
