@@ -54,30 +54,32 @@ static void init (Position *pos);
 
 static void position_set_empty (Position *pos);
 
-GtkType
-position_get_type ()
+GType
+position_get_type (void)
 {
-	static guint position_type = 0;
+	static GType type = 0;
 
-	if (!position_type) {
-		GtkTypeInfo position_info = {
-			"Position",
-			sizeof (Position),
+	if (!type) {
+		static const GTypeInfo info = {
 			sizeof (PositionClass),
-			(GtkClassInitFunc) class_init,
-			(GtkObjectInitFunc) init,
-			(GtkArgSetFunc) NULL,
-			(GtkArgGetFunc) NULL
-		};
-		position_type = gtk_type_unique (gtk_object_get_type (),
-						 &position_info);
+			NULL,
+			NULL,
+			(GClassInitFunc) class_init,
+			NULL,
+			NULL,
+			sizeof (Position),
+			0,
+			(GInstanceInitFunc) init
+		};		
+
+		type = g_type_register_static (G_TYPE_OBJECT, "Position", &info, 0);
 	}
 
-	return position_type;
+	return type;
 }
 
 static void
-finalize (GtkObject *object)
+finalize (GObject *object)
 {
 	Position *pos = (Position *) object;
 
@@ -87,11 +89,11 @@ finalize (GtkObject *object)
 }
 
 static void
-class_init (PositionClass *class)
+class_init (PositionClass *klass)
 {
-	GtkObjectClass *object_class;
+	GObjectClass *object_class;
 
-	object_class = (GtkObjectClass*) class;
+	object_class = (GObjectClass *)klass;
 
 	object_class->finalize = finalize;
 }
@@ -104,21 +106,21 @@ init (Position *pos)
 	position_set_empty (pos);
 }
 
-GtkObject *
-position_new ()
+GObject *
+position_new (void)
 {
-	return GTK_OBJECT (gtk_type_new (position_get_type ()));
+	return g_object_new (TYPE_POSITION, NULL);
 }
 
-GtkObject *
+GObject *
 position_new_initial ()
 {
 	Position *pos;
 
-	pos = POSITION (position_new ());
+	pos = g_object_new (TYPE_POSITION, NULL);
 	position_set_initial (pos);
 
-	return GTK_OBJECT (pos);
+	return G_OBJECT (pos);
 }
 
 Position *
@@ -263,7 +265,7 @@ position_move_white (Position *pos, Square from, Square to)
 	switch (piece) {
 	case WP :
 		/* If we are promoting a pawn */
-		if (to & 128) {
+		if (IS_PROMOTION (to)) {
 			new_to = (to & 7) + A8;            
 			piece = ((to & 127) >> 3 ) + WP - 1;
 
@@ -350,7 +352,7 @@ position_move_black (Position *pos, Square from, Square to)
 	switch (piece) {
 	case BP :
 		/* If we are promoting a pawn */
-		if (to & 128) {
+		if (IS_PROMOTION (to)) {
 			new_to = (to & 7) + A1;
 			piece = ((to & 127) >> 3) + BP - 1;
 
@@ -586,7 +588,7 @@ position_move_reverse_white (Position *pos, Square from, Square to)
 
 	pos->priv->tomove = WHITE; /* change tomove */
 
-	if (to & 128) {
+	if (IS_PROMOTION (to)) {
                 /* Promotion */
 		position_move_reverse_promotion_white (pos, from, to);
 		return;
@@ -652,7 +654,7 @@ position_move_reverse_black (Position *pos, Square from, Square to)
 
 	pos->priv->tomove = BLACK;      /* change tomove */
 
-	if (to & 128) {
+	if (IS_PROMOTION (to)) {
                 /* Promotion */
 		position_move_reverse_promotion_black (pos, from, to);
 		return;
