@@ -16,10 +16,13 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
  */
 
-#include "gnome_chess.h"
+#include <stdio.h>
+#include "prefs.h"
+#include "sound.h"
 
-void gnomechess_sound_enginemove(void) {
-	if (prefs->sound_beeponmove) {
-		putc(7,stderr);
-	}
+void 
+sound_enginemove (void) 
+{
+	if (prefs_get_beeponmove ())
+		putc (7,stderr);
 }
